macro_rules! skip_unless_java {
() => { ... };
}Expand description
Place at the top of any test that needs the Java archive. Skips the test
(early-returns Ok(())) when java is not on PATH. Requires the test to
return a Result<(), _>.
macro_rules! skip_unless_java {
() => { ... };
}Place at the top of any test that needs the Java archive. Skips the test
(early-returns Ok(())) when java is not on PATH. Requires the test to
return a Result<(), _>.