AeronArchivePersistentSubscriptionListener

Struct AeronArchivePersistentSubscriptionListener 

pub struct AeronArchivePersistentSubscriptionListener { /* private fields */ }
Listener for events from a persistent subscription.

All callbacks are invoked from the thread that calls aeron_archive_persistent_subscription_poll or aeron_archive_persistent_subscription_controlled_poll.

Implementations

Source

impl AeronArchivePersistentSubscriptionListener

pub fn new( on_live_joined: Option<unsafe extern "C" fn(clientd: *mut c_void)>, on_live_left: Option<unsafe extern "C" fn(clientd: *mut c_void)>, on_error: Option<unsafe extern "C" fn(clientd: *mut c_void, errcode: c_int, message: *const c_char)>, clientd: *mut c_void, ) -> Result<Self, AeronCError>

pub fn new_zeroed_on_heap() -> Self

creates zeroed struct where the underlying c struct is on the heap

pub fn new_zeroed_on_stack() -> Self

creates zeroed struct where the underlying c struct is on the stack (Use with care)

pub fn on_live_joined( &self, ) -> Option<unsafe extern "C" fn(clientd: *mut c_void)>

pub fn on_live_left(&self) -> Option<unsafe extern "C" fn(clientd: *mut c_void)>

pub fn on_error( &self, ) -> Option<unsafe extern "C" fn(clientd: *mut c_void, errcode: c_int, message: *const c_char)>

pub fn clientd(&self) -> *mut c_void

pub fn get_inner(&self) -> *mut aeron_archive_persistent_subscription_listener_t

pub unsafe fn get_inner_mut( &self, ) -> &mut aeron_archive_persistent_subscription_listener_t

Mutable access to the underlying C struct, minted from &self: nothing prevents two live &mut at once, so the caller must ensure exclusive access for the lifetime of the returned reference.

Safety

No other reference (& or &mut) to the underlying struct may be alive while the returned &mut is in use.

pub fn get_inner_ref(&self) -> &aeron_archive_persistent_subscription_listener_t

Source

impl AeronArchivePersistentSubscriptionListener

pub fn clone_struct(&self) -> Self

Regular clone just increases the reference count of underlying count. clone_struct shallow copies the content of the underlying struct on heap.

NOTE: if the struct has references to other structs these will not be copied

Must be only used on structs which has no init/clean up methods. So its dangerous to use with Aeron/AeronContext/AeronPublication/AeronSubscription More intended for AeronArchiveRecordingDescriptor (note strings will not work as its a shallow copy)