pub struct AeronArchiveRecordingDescriptor { /* private fields */ }Expand description
Struct containing the details of a recording
Implementations
Sourceimpl AeronArchiveRecordingDescriptor
impl AeronArchiveRecordingDescriptor
pub fn new( control_session_id: i64, correlation_id: i64, recording_id: i64, start_timestamp: i64, stop_timestamp: i64, start_position: i64, stop_position: i64, initial_term_id: i32, segment_file_length: i32, term_buffer_length: i32, mtu_length: i32, session_id: i32, stream_id: i32, stripped_channel: &mut [u8], original_channel: &mut [u8], source_identity: &mut [u8], ) -> Result<Self, AeronCError>
Sourcepub fn new_zeroed_on_heap() -> Self
pub fn new_zeroed_on_heap() -> Self
creates zeroed struct where the underlying c struct is on the heap
Sourcepub fn new_zeroed_on_stack() -> Self
pub fn new_zeroed_on_stack() -> Self
creates zeroed struct where the underlying c struct is on the stack (Use with care)
pub fn control_session_id(&self) -> i64
pub fn correlation_id(&self) -> i64
pub fn recording_id(&self) -> i64
pub fn start_timestamp(&self) -> i64
pub fn stop_timestamp(&self) -> i64
pub fn start_position(&self) -> i64
pub fn stop_position(&self) -> i64
pub fn initial_term_id(&self) -> i32
pub fn segment_file_length(&self) -> i32
pub fn term_buffer_length(&self) -> i32
pub fn mtu_length(&self) -> i32
pub fn session_id(&self) -> i32
pub fn stream_id(&self) -> i32
pub fn stripped_channel(&self) -> &str
pub fn stripped_channel_length(&self) -> usize
pub fn original_channel(&self) -> &str
pub fn original_channel_length(&self) -> usize
pub fn source_identity(&self) -> &str
pub fn source_identity_length(&self) -> usize
pub fn get_inner(&self) -> *mut aeron_archive_recording_descriptor_t
Sourcepub unsafe fn get_inner_mut(&self) -> &mut aeron_archive_recording_descriptor_t
pub unsafe fn get_inner_mut(&self) -> &mut aeron_archive_recording_descriptor_t
Mutable access to the underlying C struct, minted from &self: nothing
prevents two live &mut at once, so the caller must ensure exclusive
access for the lifetime of the returned reference.
Safety
No other reference (& or &mut) to the underlying struct may be
alive while the returned &mut is in use.
pub fn get_inner_ref(&self) -> &aeron_archive_recording_descriptor_t
Sourceimpl AeronArchiveRecordingDescriptor
impl AeronArchiveRecordingDescriptor
Sourcepub fn clone_struct(&self) -> Self
pub fn clone_struct(&self) -> Self
Regular clone just increases the reference count of underlying count.
clone_struct shallow copies the content of the underlying struct on heap.
NOTE: if the struct has references to other structs these will not be copied
Must be only used on structs which has no init/clean up methods. So its dangerous to use with Aeron/AeronContext/AeronPublication/AeronSubscription More intended for AeronArchiveRecordingDescriptor (note strings will not work as its a shallow copy)