pub struct AeronArchiveRecordingSubscriptionDescriptor { /* private fields */ }Expand description
Struct containing the details of a recording subscription
Implementations
Sourceimpl AeronArchiveRecordingSubscriptionDescriptor
impl AeronArchiveRecordingSubscriptionDescriptor
pub fn new( control_session_id: i64, correlation_id: i64, subscription_id: i64, stream_id: i32, stripped_channel: &mut [u8], ) -> Result<Self, AeronCError>
Sourcepub fn new_zeroed_on_heap() -> Self
pub fn new_zeroed_on_heap() -> Self
creates zeroed struct where the underlying c struct is on the heap
Sourcepub fn new_zeroed_on_stack() -> Self
pub fn new_zeroed_on_stack() -> Self
creates zeroed struct where the underlying c struct is on the stack (Use with care)
pub fn control_session_id(&self) -> i64
pub fn correlation_id(&self) -> i64
pub fn subscription_id(&self) -> i64
pub fn stream_id(&self) -> i32
pub fn stripped_channel(&self) -> &str
pub fn stripped_channel_length(&self) -> usize
pub fn get_inner( &self, ) -> *mut aeron_archive_recording_subscription_descriptor_t
Sourcepub unsafe fn get_inner_mut(
&self,
) -> &mut aeron_archive_recording_subscription_descriptor_t
pub unsafe fn get_inner_mut( &self, ) -> &mut aeron_archive_recording_subscription_descriptor_t
Mutable access to the underlying C struct, minted from &self: nothing
prevents two live &mut at once, so the caller must ensure exclusive
access for the lifetime of the returned reference.
Safety
No other reference (& or &mut) to the underlying struct may be
alive while the returned &mut is in use.
pub fn get_inner_ref( &self, ) -> &aeron_archive_recording_subscription_descriptor_t
Sourceimpl AeronArchiveRecordingSubscriptionDescriptor
impl AeronArchiveRecordingSubscriptionDescriptor
Sourcepub fn clone_struct(&self) -> Self
pub fn clone_struct(&self) -> Self
Regular clone just increases the reference count of underlying count.
clone_struct shallow copies the content of the underlying struct on heap.
NOTE: if the struct has references to other structs these will not be copied
Must be only used on structs which has no init/clean up methods. So its dangerous to use with Aeron/AeronContext/AeronPublication/AeronSubscription More intended for AeronArchiveRecordingDescriptor (note strings will not work as its a shallow copy)