pub struct AeronAsyncDestination { /* private fields */ }Implementations
Sourceimpl AeronAsyncDestination
impl AeronAsyncDestination
Sourcepub fn aeron_publication_async_add_destination(
client: &Aeron,
publication: &AeronPublication,
uri: &CStr,
) -> Result<Self, AeronCError>
pub fn aeron_publication_async_add_destination( client: &Aeron, publication: &AeronPublication, uri: &CStr, ) -> Result<Self, AeronCError>
Sourcepub fn aeron_exclusive_publication_async_add_destination(
client: &Aeron,
publication: &AeronExclusivePublication,
uri: &CStr,
) -> Result<Self, AeronCError>
pub fn aeron_exclusive_publication_async_add_destination( client: &Aeron, publication: &AeronExclusivePublication, uri: &CStr, ) -> Result<Self, AeronCError>
Sourcepub fn aeron_subscription_async_add_destination(
client: &Aeron,
subscription: &AeronSubscription,
uri: &CStr,
) -> Result<Self, AeronCError>
pub fn aeron_subscription_async_add_destination( client: &Aeron, subscription: &AeronSubscription, uri: &CStr, ) -> Result<Self, AeronCError>
Sourcepub fn aeron_publication_async_destination_poll(
&self,
) -> Result<i32, AeronCError>
pub fn aeron_publication_async_destination_poll( &self, ) -> Result<i32, AeronCError>
Poll the completion of the add/remove of a destination to/from a publication.
Return
0 for not complete (try again), 1 for completed successfully, or -1 for an error.
Sourcepub fn aeron_exclusive_publication_async_destination_poll(
&self,
) -> Result<i32, AeronCError>
pub fn aeron_exclusive_publication_async_destination_poll( &self, ) -> Result<i32, AeronCError>
Poll the completion of the add/remove of a destination to/from an exclusive publication.
Return
0 for not complete (try again), 1 for completed successfully, or -1 for an error.
Sourcepub fn aeron_subscription_async_destination_poll(
&self,
) -> Result<i32, AeronCError>
pub fn aeron_subscription_async_destination_poll( &self, ) -> Result<i32, AeronCError>
Poll the completion of add/remove of a destination to/from a subscription.
Return
0 for not complete (try again), 1 for completed successfully, or -1 for an error.
Sourcepub fn get_registration_id(&self) -> i64
pub fn get_registration_id(&self) -> i64
Gets the registration_id for the destination command supplied. Note that this is the correlation_id used for the specified destination command, not the registration_id for the original parent resource (publication, subscription).
Return
correlation_id sent to driver.
pub fn get_inner(&self) -> *mut aeron_async_destination_t
Sourcepub unsafe fn get_inner_mut(&self) -> &mut aeron_async_destination_t
pub unsafe fn get_inner_mut(&self) -> &mut aeron_async_destination_t
Mutable access to the underlying C struct, minted from &self: nothing
prevents two live &mut at once, so the caller must ensure exclusive
access for the lifetime of the returned reference.
Safety
No other reference (& or &mut) to the underlying struct may be
alive while the returned &mut is in use.
pub fn get_inner_ref(&self) -> &aeron_async_destination_t