pub struct AeronCncMetadata { /* private fields */ }Implementations
Sourceimpl AeronCncMetadata
impl AeronCncMetadata
pub fn new( cnc_version: i32, to_driver_buffer_length: i32, to_clients_buffer_length: i32, counter_metadata_buffer_length: i32, counter_values_buffer_length: i32, error_log_buffer_length: i32, client_liveness_timeout: i64, start_timestamp: i64, pid: i64, file_page_size: i32, ) -> Result<Self, AeronCError>
Sourcepub fn new_zeroed_on_heap() -> Self
pub fn new_zeroed_on_heap() -> Self
creates zeroed struct where the underlying c struct is on the heap
Sourcepub fn new_zeroed_on_stack() -> Self
pub fn new_zeroed_on_stack() -> Self
creates zeroed struct where the underlying c struct is on the stack (Use with care)
pub fn cnc_version(&self) -> i32
pub fn to_driver_buffer_length(&self) -> i32
pub fn to_clients_buffer_length(&self) -> i32
pub fn counter_metadata_buffer_length(&self) -> i32
pub fn counter_values_buffer_length(&self) -> i32
pub fn error_log_buffer_length(&self) -> i32
pub fn client_liveness_timeout(&self) -> i64
pub fn start_timestamp(&self) -> i64
pub fn pid(&self) -> i64
pub fn file_page_size(&self) -> i32
pub fn aeron_cnc_version_volatile(&self) -> i32
pub fn get_inner(&self) -> *mut aeron_cnc_metadata_t
Sourcepub unsafe fn get_inner_mut(&self) -> &mut aeron_cnc_metadata_t
pub unsafe fn get_inner_mut(&self) -> &mut aeron_cnc_metadata_t
Mutable access to the underlying C struct, minted from &self: nothing
prevents two live &mut at once, so the caller must ensure exclusive
access for the lifetime of the returned reference.
Safety
No other reference (& or &mut) to the underlying struct may be
alive while the returned &mut is in use.
pub fn get_inner_ref(&self) -> &aeron_cnc_metadata_t
Sourceimpl AeronCncMetadata
impl AeronCncMetadata
Sourcepub fn clone_struct(&self) -> Self
pub fn clone_struct(&self) -> Self
Regular clone just increases the reference count of underlying count.
clone_struct shallow copies the content of the underlying struct on heap.
NOTE: if the struct has references to other structs these will not be copied
Must be only used on structs which has no init/clean up methods. So its dangerous to use with Aeron/AeronContext/AeronPublication/AeronSubscription More intended for AeronArchiveRecordingDescriptor (note strings will not work as its a shallow copy)
Sourceimpl AeronCncMetadata
impl AeronCncMetadata
Sourcepub fn load_from_file(aeron_dir: &str) -> Result<Self, AeronCError>
pub fn load_from_file(aeron_dir: &str) -> Result<Self, AeronCError>
allocates on heap
Sourcepub fn read_from_file(
aeron_dir: &CString,
handler: impl FnMut(Self),
) -> Result<(), AeronCError>
pub fn read_from_file( aeron_dir: &CString, handler: impl FnMut(Self), ) -> Result<(), AeronCError>
allocates on stack