pub struct AeronCounterMetadataDescriptor { /* private fields */ }Implementations
Sourceimpl AeronCounterMetadataDescriptor
impl AeronCounterMetadataDescriptor
pub fn new( state: i32, type_id: i32, free_for_reuse_deadline_ms: i64, key: [u8; 112], label_length: i32, label: [u8; 380], ) -> Result<Self, AeronCError>
Sourcepub fn new_zeroed_on_heap() -> Self
pub fn new_zeroed_on_heap() -> Self
creates zeroed struct where the underlying c struct is on the heap
Sourcepub fn new_zeroed_on_stack() -> Self
pub fn new_zeroed_on_stack() -> Self
creates zeroed struct where the underlying c struct is on the stack (Use with care)
pub fn state(&self) -> i32
pub fn type_id(&self) -> i32
pub fn free_for_reuse_deadline_ms(&self) -> i64
pub fn key(&self) -> [u8; 112]
pub fn label_length(&self) -> i32
pub fn label(&self) -> [u8; 380]
pub fn get_inner(&self) -> *mut aeron_counter_metadata_descriptor_t
Sourcepub unsafe fn get_inner_mut(&self) -> &mut aeron_counter_metadata_descriptor_t
pub unsafe fn get_inner_mut(&self) -> &mut aeron_counter_metadata_descriptor_t
Mutable access to the underlying C struct, minted from &self: nothing
prevents two live &mut at once, so the caller must ensure exclusive
access for the lifetime of the returned reference.
Safety
No other reference (& or &mut) to the underlying struct may be
alive while the returned &mut is in use.
pub fn get_inner_ref(&self) -> &aeron_counter_metadata_descriptor_t
Sourceimpl AeronCounterMetadataDescriptor
impl AeronCounterMetadataDescriptor
Sourcepub fn clone_struct(&self) -> Self
pub fn clone_struct(&self) -> Self
Regular clone just increases the reference count of underlying count.
clone_struct shallow copies the content of the underlying struct on heap.
NOTE: if the struct has references to other structs these will not be copied
Must be only used on structs which has no init/clean up methods. So its dangerous to use with Aeron/AeronContext/AeronPublication/AeronSubscription More intended for AeronArchiveRecordingDescriptor (note strings will not work as its a shallow copy)