pub struct AeronCounterValueDescriptor { /* private fields */ }Implementations
Sourceimpl AeronCounterValueDescriptor
impl AeronCounterValueDescriptor
pub fn new( counter_value: i64, registration_id: i64, owner_id: i64, reference_id: i64, pad1: [u8; 96], ) -> Result<Self, AeronCError>
Sourcepub fn new_zeroed_on_heap() -> Self
pub fn new_zeroed_on_heap() -> Self
creates zeroed struct where the underlying c struct is on the heap
Sourcepub fn new_zeroed_on_stack() -> Self
pub fn new_zeroed_on_stack() -> Self
creates zeroed struct where the underlying c struct is on the stack (Use with care)
pub fn counter_value(&self) -> i64
pub fn registration_id(&self) -> i64
pub fn owner_id(&self) -> i64
pub fn reference_id(&self) -> i64
pub fn pad1(&self) -> [u8; 96]
pub fn get_inner(&self) -> *mut aeron_counter_value_descriptor_t
Sourcepub unsafe fn get_inner_mut(&self) -> &mut aeron_counter_value_descriptor_t
pub unsafe fn get_inner_mut(&self) -> &mut aeron_counter_value_descriptor_t
Mutable access to the underlying C struct, minted from &self: nothing
prevents two live &mut at once, so the caller must ensure exclusive
access for the lifetime of the returned reference.
Safety
No other reference (& or &mut) to the underlying struct may be
alive while the returned &mut is in use.
pub fn get_inner_ref(&self) -> &aeron_counter_value_descriptor_t
Sourceimpl AeronCounterValueDescriptor
impl AeronCounterValueDescriptor
Sourcepub fn clone_struct(&self) -> Self
pub fn clone_struct(&self) -> Self
Regular clone just increases the reference count of underlying count.
clone_struct shallow copies the content of the underlying struct on heap.
NOTE: if the struct has references to other structs these will not be copied
Must be only used on structs which has no init/clean up methods. So its dangerous to use with Aeron/AeronContext/AeronPublication/AeronSubscription More intended for AeronArchiveRecordingDescriptor (note strings will not work as its a shallow copy)