pub struct AeronHeaderValues { /* private fields */ }Implementations
Sourceimpl AeronHeaderValues
impl AeronHeaderValues
pub fn new( frame: AeronHeaderValuesFrame, initial_term_id: i32, position_bits_to_shift: usize, ) -> Result<Self, AeronCError>
Sourcepub fn new_zeroed_on_heap() -> Self
pub fn new_zeroed_on_heap() -> Self
creates zeroed struct where the underlying c struct is on the heap
Sourcepub fn new_zeroed_on_stack() -> Self
pub fn new_zeroed_on_stack() -> Self
creates zeroed struct where the underlying c struct is on the stack (Use with care)
pub fn frame(&self) -> AeronHeaderValuesFrame
pub fn initial_term_id(&self) -> i32
pub fn position_bits_to_shift(&self) -> usize
pub fn get_inner(&self) -> *mut aeron_header_values_t
Sourcepub unsafe fn get_inner_mut(&self) -> &mut aeron_header_values_t
pub unsafe fn get_inner_mut(&self) -> &mut aeron_header_values_t
Mutable access to the underlying C struct, minted from &self: nothing
prevents two live &mut at once, so the caller must ensure exclusive
access for the lifetime of the returned reference.
Safety
No other reference (& or &mut) to the underlying struct may be
alive while the returned &mut is in use.
pub fn get_inner_ref(&self) -> &aeron_header_values_t
Sourceimpl AeronHeaderValues
impl AeronHeaderValues
Sourcepub fn clone_struct(&self) -> Self
pub fn clone_struct(&self) -> Self
Regular clone just increases the reference count of underlying count.
clone_struct shallow copies the content of the underlying struct on heap.
NOTE: if the struct has references to other structs these will not be copied
Must be only used on structs which has no init/clean up methods. So its dangerous to use with Aeron/AeronContext/AeronPublication/AeronSubscription More intended for AeronArchiveRecordingDescriptor (note strings will not work as its a shallow copy)