pub struct AeronLogbufferMetadata { /* private fields */ }Implementations
Sourceimpl AeronLogbufferMetadata
impl AeronLogbufferMetadata
pub fn new( term_tail_counters: [i64; 3], active_term_count: i32, pad1: [u8; 100], end_of_stream_position: i64, is_connected: i32, active_transport_count: i32, pad2: [u8; 112], correlation_id: i64, initial_term_id: i32, default_frame_header_length: i32, mtu_length: i32, term_length: i32, page_size: i32, publication_window_length: i32, receiver_window_length: i32, socket_sndbuf_length: i32, os_default_socket_sndbuf_length: i32, os_max_socket_sndbuf_length: i32, socket_rcvbuf_length: i32, os_default_socket_rcvbuf_length: i32, os_max_socket_rcvbuf_length: i32, max_resend: i32, default_header: [u8; 128], entity_tag: i64, response_correlation_id: i64, linger_timeout_ns: i64, untethered_window_limit_timeout_ns: i64, untethered_resting_timeout_ns: i64, group: u8, is_response: u8, rejoin: u8, reliable: u8, sparse: u8, signal_eos: u8, spies_simulate_connection: u8, tether: u8, is_publication_revoked: u8, type_: u8, pad3: [u8; 2], untethered_linger_timeout_ns: i64, ) -> Result<Self, AeronCError>
Sourcepub fn new_zeroed_on_heap() -> Self
pub fn new_zeroed_on_heap() -> Self
creates zeroed struct where the underlying c struct is on the heap
Sourcepub fn new_zeroed_on_stack() -> Self
pub fn new_zeroed_on_stack() -> Self
creates zeroed struct where the underlying c struct is on the stack (Use with care)
pub fn term_tail_counters(&self) -> [i64; 3]
pub fn active_term_count(&self) -> i32
pub fn pad1(&self) -> [u8; 100]
pub fn end_of_stream_position(&self) -> i64
pub fn is_connected(&self) -> i32
pub fn active_transport_count(&self) -> i32
pub fn pad2(&self) -> [u8; 112]
pub fn correlation_id(&self) -> i64
pub fn initial_term_id(&self) -> i32
pub fn default_frame_header_length(&self) -> i32
pub fn mtu_length(&self) -> i32
pub fn term_length(&self) -> i32
pub fn page_size(&self) -> i32
pub fn publication_window_length(&self) -> i32
pub fn receiver_window_length(&self) -> i32
pub fn socket_sndbuf_length(&self) -> i32
pub fn os_default_socket_sndbuf_length(&self) -> i32
pub fn os_max_socket_sndbuf_length(&self) -> i32
pub fn socket_rcvbuf_length(&self) -> i32
pub fn os_default_socket_rcvbuf_length(&self) -> i32
pub fn os_max_socket_rcvbuf_length(&self) -> i32
pub fn max_resend(&self) -> i32
pub fn default_header(&self) -> [u8; 128]
pub fn entity_tag(&self) -> i64
pub fn response_correlation_id(&self) -> i64
pub fn linger_timeout_ns(&self) -> i64
pub fn untethered_window_limit_timeout_ns(&self) -> i64
pub fn untethered_resting_timeout_ns(&self) -> i64
pub fn group(&self) -> u8
pub fn is_response(&self) -> u8
pub fn rejoin(&self) -> u8
pub fn reliable(&self) -> u8
pub fn sparse(&self) -> u8
pub fn signal_eos(&self) -> u8
pub fn spies_simulate_connection(&self) -> u8
pub fn tether(&self) -> u8
pub fn is_publication_revoked(&self) -> u8
pub fn type_(&self) -> u8
pub fn pad3(&self) -> [u8; 2]
pub fn untethered_linger_timeout_ns(&self) -> i64
pub fn get_inner(&self) -> *mut aeron_logbuffer_metadata_t
Sourcepub unsafe fn get_inner_mut(&self) -> &mut aeron_logbuffer_metadata_t
pub unsafe fn get_inner_mut(&self) -> &mut aeron_logbuffer_metadata_t
Mutable access to the underlying C struct, minted from &self: nothing
prevents two live &mut at once, so the caller must ensure exclusive
access for the lifetime of the returned reference.
Safety
No other reference (& or &mut) to the underlying struct may be
alive while the returned &mut is in use.
pub fn get_inner_ref(&self) -> &aeron_logbuffer_metadata_t
Sourceimpl AeronLogbufferMetadata
impl AeronLogbufferMetadata
Sourcepub fn clone_struct(&self) -> Self
pub fn clone_struct(&self) -> Self
Regular clone just increases the reference count of underlying count.
clone_struct shallow copies the content of the underlying struct on heap.
NOTE: if the struct has references to other structs these will not be copied
Must be only used on structs which has no init/clean up methods. So its dangerous to use with Aeron/AeronContext/AeronPublication/AeronSubscription More intended for AeronArchiveRecordingDescriptor (note strings will not work as its a shallow copy)