pub struct AeronMappedRawLog { /* private fields */ }Implementations
Sourceimpl AeronMappedRawLog
impl AeronMappedRawLog
pub fn new( term_buffers: [aeron_mapped_buffer_t; 3], log_meta_data: AeronMappedBuffer, mapped_file: AeronMappedFile, term_length: usize, ) -> Result<Self, AeronCError>
Sourcepub fn new_zeroed_on_heap() -> Self
pub fn new_zeroed_on_heap() -> Self
creates zeroed struct where the underlying c struct is on the heap
Sourcepub fn new_zeroed_on_stack() -> Self
pub fn new_zeroed_on_stack() -> Self
creates zeroed struct where the underlying c struct is on the stack (Use with care)
pub fn term_buffers(&self) -> [aeron_mapped_buffer_t; 3]
pub fn log_meta_data(&self) -> AeronMappedBuffer
pub fn mapped_file(&self) -> AeronMappedFile
pub fn term_length(&self) -> usize
pub fn aeron_raw_log_map( &self, path: &CStr, use_sparse_files: bool, term_length: u64, page_size: u64, ) -> Result<i32, AeronCError>
pub fn aeron_raw_log_map_existing( &self, path: &CStr, pre_touch: bool, ) -> Result<i32, AeronCError>
pub fn aeron_raw_log_free(&self, filename: &CStr) -> bool
pub fn get_inner(&self) -> *mut aeron_mapped_raw_log_t
Sourcepub unsafe fn get_inner_mut(&self) -> &mut aeron_mapped_raw_log_t
pub unsafe fn get_inner_mut(&self) -> &mut aeron_mapped_raw_log_t
Mutable access to the underlying C struct, minted from &self: nothing
prevents two live &mut at once, so the caller must ensure exclusive
access for the lifetime of the returned reference.
Safety
No other reference (& or &mut) to the underlying struct may be
alive while the returned &mut is in use.
pub fn get_inner_ref(&self) -> &aeron_mapped_raw_log_t
Sourceimpl AeronMappedRawLog
impl AeronMappedRawLog
Sourcepub fn clone_struct(&self) -> Self
pub fn clone_struct(&self) -> Self
Regular clone just increases the reference count of underlying count.
clone_struct shallow copies the content of the underlying struct on heap.
NOTE: if the struct has references to other structs these will not be copied
Must be only used on structs which has no init/clean up methods. So its dangerous to use with Aeron/AeronContext/AeronPublication/AeronSubscription More intended for AeronArchiveRecordingDescriptor (note strings will not work as its a shallow copy)