pub struct AeronResponseSetupHeader { /* private fields */ }Implementations
Sourceimpl AeronResponseSetupHeader
impl AeronResponseSetupHeader
pub fn new( frame_header: AeronFrameHeader, session_id: i32, stream_id: i32, response_session_id: i32, ) -> Result<Self, AeronCError>
Sourcepub fn new_zeroed_on_heap() -> Self
pub fn new_zeroed_on_heap() -> Self
creates zeroed struct where the underlying c struct is on the heap
Sourcepub fn new_zeroed_on_stack() -> Self
pub fn new_zeroed_on_stack() -> Self
creates zeroed struct where the underlying c struct is on the stack (Use with care)
pub fn frame_header(&self) -> AeronFrameHeader
pub fn session_id(&self) -> i32
pub fn stream_id(&self) -> i32
pub fn response_session_id(&self) -> i32
pub fn get_inner(&self) -> *mut aeron_response_setup_header_t
Sourcepub unsafe fn get_inner_mut(&self) -> &mut aeron_response_setup_header_t
pub unsafe fn get_inner_mut(&self) -> &mut aeron_response_setup_header_t
Mutable access to the underlying C struct, minted from &self: nothing
prevents two live &mut at once, so the caller must ensure exclusive
access for the lifetime of the returned reference.
Safety
No other reference (& or &mut) to the underlying struct may be
alive while the returned &mut is in use.
pub fn get_inner_ref(&self) -> &aeron_response_setup_header_t
Sourceimpl AeronResponseSetupHeader
impl AeronResponseSetupHeader
Sourcepub fn clone_struct(&self) -> Self
pub fn clone_struct(&self) -> Self
Regular clone just increases the reference count of underlying count.
clone_struct shallow copies the content of the underlying struct on heap.
NOTE: if the struct has references to other structs these will not be copied
Must be only used on structs which has no init/clean up methods. So its dangerous to use with Aeron/AeronContext/AeronPublication/AeronSubscription More intended for AeronArchiveRecordingDescriptor (note strings will not work as its a shallow copy)