pub struct AeronUriStringBuilder { /* private fields */ }Implementations
Sourceimpl AeronUriStringBuilder
impl AeronUriStringBuilder
Sourcepub fn new_zeroed_on_heap() -> Self
pub fn new_zeroed_on_heap() -> Self
creates zeroed struct where the underlying c struct is on the heap
Sourcepub fn new_zeroed_on_stack() -> Self
pub fn new_zeroed_on_stack() -> Self
creates zeroed struct where the underlying c struct is on the stack (Use with care)
pub fn params(&self) -> AeronStrToPtrHashMap
pub fn closed(&self) -> bool
pub fn put(&self, key: &CStr, value: &CStr) -> Result<i32, AeronCError>
pub fn put_int32(&self, key: &CStr, value: i32) -> Result<i32, AeronCError>
pub fn put_int64(&self, key: &CStr, value: i64) -> Result<i32, AeronCError>
pub fn get(&self, key: &CStr) -> &str
pub fn sprint(&self, buffer: &mut [u8]) -> Result<i32, AeronCError>
pub fn sprint_as_string(&self, max_length: usize) -> Result<String, AeronCError>
Sourcepub fn sprint_into(
&self,
dst_truncate_to_capacity: &mut String,
) -> Result<i32, AeronCError>
pub fn sprint_into( &self, dst_truncate_to_capacity: &mut String, ) -> Result<i32, AeronCError>
NOTE: allocation friendly method, the string capacity must be set as it will truncate string to capacity it will never grow the string. So if you pass String::new() it will write 0 chars
pub fn set_initial_position( &self, position: i64, initial_term_id: i32, term_length: i32, ) -> Result<i32, AeronCError>
pub fn get_inner(&self) -> *mut aeron_uri_string_builder_t
Sourcepub unsafe fn get_inner_mut(&self) -> &mut aeron_uri_string_builder_t
pub unsafe fn get_inner_mut(&self) -> &mut aeron_uri_string_builder_t
Mutable access to the underlying C struct, minted from &self: nothing
prevents two live &mut at once, so the caller must ensure exclusive
access for the lifetime of the returned reference.
Safety
No other reference (& or &mut) to the underlying struct may be
alive while the returned &mut is in use.
pub fn get_inner_ref(&self) -> &aeron_uri_string_builder_t
Sourceimpl AeronUriStringBuilder
impl AeronUriStringBuilder
Sourcepub fn ipc() -> Result<Self, AeronCError>
pub fn ipc() -> Result<Self, AeronCError>
Fresh builder for an aeron:ipc channel.
Sourcepub fn udp(endpoint: &str) -> Result<Self, AeronCError>
pub fn udp(endpoint: &str) -> Result<Self, AeronCError>
Fresh builder for an aeron:udp channel with the given endpoint (host:port).
Sourcepub fn udp_control(
control: &str,
mode: ControlMode,
) -> Result<Self, AeronCError>
pub fn udp_control( control: &str, mode: ControlMode, ) -> Result<Self, AeronCError>
Fresh builder for an aeron:udp multi-destination channel with the given
control endpoint and ControlMode (Dynamic for MDC publications,
Manual for MDS subscriptions/publications, Response for response channels).
Sourcepub fn init_new(&self) -> Result<i32, AeronCError>
pub fn init_new(&self) -> Result<i32, AeronCError>
Initialize a new AeronUriStringBuilder. If already initialized, it will close the previous builder to prevent memory leaks.
Sourcepub fn init_on_string(&self, uri: &CStr) -> Result<i32, AeronCError>
pub fn init_on_string(&self, uri: &CStr) -> Result<i32, AeronCError>
Initialize AeronUriStringBuilder with an existing URI string. If already initialized, it will close the previous builder.
pub fn build(&self, max_str_length: usize) -> Result<String, AeronCError>
pub fn put_str(&self, key: &CStr, value: &str) -> Result<&Self, AeronCError>
pub fn media(&self, value: Media) -> Result<&Self, AeronCError>
pub fn control_mode(&self, value: ControlMode) -> Result<&Self, AeronCError>
pub fn prefix(&self, value: &str) -> Result<&Self, AeronCError>
pub fn initial_term_id(&self, value: i32) -> Result<&Self, AeronCError>
pub fn term_id(&self, value: i32) -> Result<&Self, AeronCError>
pub fn term_offset(&self, value: i32) -> Result<&Self, AeronCError>
pub fn alias(&self, value: &str) -> Result<&Self, AeronCError>
pub fn term_length(&self, value: &str) -> Result<&Self, AeronCError>
pub fn linger_timeout(&self, value: i64) -> Result<&Self, AeronCError>
pub fn mtu_length(&self, value: i32) -> Result<&Self, AeronCError>
pub fn ttl(&self, value: i32) -> Result<&Self, AeronCError>
pub fn sparse_term(&self, value: bool) -> Result<&Self, AeronCError>
pub fn reliable(&self, value: bool) -> Result<&Self, AeronCError>
pub fn eos(&self, value: bool) -> Result<&Self, AeronCError>
pub fn tether(&self, value: bool) -> Result<&Self, AeronCError>
pub fn endpoint(&self, value: &str) -> Result<&Self, AeronCError>
pub fn interface(&self, value: &str) -> Result<&Self, AeronCError>
pub fn control(&self, value: &str) -> Result<&Self, AeronCError>
pub fn session_id(&self, value: &str) -> Result<&Self, AeronCError>
pub fn group(&self, value: bool) -> Result<&Self, AeronCError>
pub fn rejoin(&self, value: bool) -> Result<&Self, AeronCError>
pub fn fc(&self, value: &str) -> Result<&Self, AeronCError>
pub fn gtag(&self, value: &str) -> Result<&Self, AeronCError>
pub fn cc(&self, value: &str) -> Result<&Self, AeronCError>
pub fn spies_simulate_connection( &self, value: bool, ) -> Result<&Self, AeronCError>
pub fn ats(&self, value: bool) -> Result<&Self, AeronCError>
pub fn socket_sndbuf(&self, value: i32) -> Result<&Self, AeronCError>
pub fn socket_rcvbuf(&self, value: i32) -> Result<&Self, AeronCError>
pub fn receiver_window(&self, value: i32) -> Result<&Self, AeronCError>
pub fn media_rcv_timestamp_offset( &self, value: &str, ) -> Result<&Self, AeronCError>
pub fn channel_rcv_timestamp_offset( &self, value: &str, ) -> Result<&Self, AeronCError>
pub fn channel_snd_timestamp_offset( &self, value: &str, ) -> Result<&Self, AeronCError>
pub fn timestamp_offset_reserved( &self, value: &str, ) -> Result<&Self, AeronCError>
pub fn response_correlation_id(&self, value: i64) -> Result<&Self, AeronCError>
pub fn nak_delay(&self, value: i64) -> Result<&Self, AeronCError>
pub fn untethered_window_limit_timeout( &self, value: i64, ) -> Result<&Self, AeronCError>
pub fn untethered_resting_timeout( &self, value: i64, ) -> Result<&Self, AeronCError>
pub fn max_resend(&self, value: i32) -> Result<&Self, AeronCError>
pub fn stream_id(&self, value: i32) -> Result<&Self, AeronCError>
pub fn publication_window(&self, value: i32) -> Result<&Self, AeronCError>
pub fn build_into(&self, dst: &mut String) -> Result<(), AeronCError>
Sourcepub fn remove_str(&self, key: &str) -> Result<i32, AeronCError>
pub fn remove_str(&self, key: &str) -> Result<i32, AeronCError>