PersistentSubscriptionBuilder

Struct PersistentSubscriptionBuilder 

pub struct PersistentSubscriptionBuilder { /* private fields */ }
Builder for configuring and creating a persistent subscription. This provides a fluent interface for setting up a persistent subscription with proper CString handling.

Implementations

Source

impl PersistentSubscriptionBuilder

pub fn new() -> Result<Self, AeronCError>

Create a new builder with a default context.

pub fn aeron(self, aeron: &Aeron) -> Result<Self, AeronCError>

Set the Aeron client to use.

pub fn archive_context( self, ctx: &AeronArchiveContext, ) -> Result<Self, AeronCError>

Set the archive context to use.

pub fn live_channel(self, channel: &str) -> Result<Self, AeronCError>

Set the live channel (accepts &str, handles CString conversion internally).

pub fn live_stream_id(self, id: i32) -> Result<Self, AeronCError>

Set the live stream ID.

pub fn replay_channel(self, channel: &str) -> Result<Self, AeronCError>

Set the replay channel (accepts &str, handles CString conversion internally).

pub fn replay_stream_id(self, id: i32) -> Result<Self, AeronCError>

Set the replay stream ID.

pub fn start_position(self, pos: i64) -> Result<Self, AeronCError>

Set the start position.

pub fn start_from_beginning(self) -> Result<Self, AeronCError>

Replay from the beginning of the recording (Aeron FROM_START).

pub fn start_from_live(self) -> Result<Self, AeronCError>

Skip replay and join the live stream immediately (Aeron FROM_LIVE).

pub fn recording_id(self, id: i64) -> Result<Self, AeronCError>

Set the recording ID.

pub fn listener<L: PersistentSubscriptionListener>( self, listener: L, ) -> Result<Self, AeronCError>

Set the listener for events.

pub fn state_counter(self, counter: &AeronCounter) -> Result<Self, AeronCError>

Pre-allocate the state counter so an external observer can read the PS state-machine state. If unset the PS allocates one itself. Maps to Aeron’s Context.stateCounter.

pub fn join_difference_counter( self, counter: &AeronCounter, ) -> Result<Self, AeronCError>

Counter holding the byte gap between replay and live when the live image is added. Maps to Aeron’s Context.joinDifferenceCounter.

pub fn live_left_counter( self, counter: &AeronCounter, ) -> Result<Self, AeronCError>

Counter holding the number of times the PS has dropped off the live stream. Maps to Aeron’s Context.liveLeftCounter.

pub fn live_joined_counter( self, counter: &AeronCounter, ) -> Result<Self, AeronCError>

Counter holding the number of times the PS has switched to the live stream. Maps to Aeron’s Context.liveJoinedCounter.

pub fn build(self) -> Result<AeronArchivePersistentSubscription, AeronCError>

Build the persistent subscription.