pub struct RecordingPos;Implementations
Sourceimpl RecordingPos
impl RecordingPos
pub fn find_counter_id_by_session( counter_reader: &AeronCountersReader, session_id: i32, ) -> i32
pub fn find_counter_id_by_recording_id( counter_reader: &AeronCountersReader, recording_id: i64, ) -> i32
Sourcepub fn get_recording_id_block(
counters_reader: &AeronCountersReader,
counter_id: i32,
wait: Duration,
) -> Result<i64, AeronCError>
pub fn get_recording_id_block( counters_reader: &AeronCountersReader, counter_id: i32, wait: Duration, ) -> Result<i64, AeronCError>
Return the recordingId embedded in the key of the given counter if it is indeed a “recording position” counter. Otherwise return -1.
Sourcepub fn get_recording_id(
counters_reader: &AeronCountersReader,
counter_id: i32,
) -> Result<i64, AeronCError>
pub fn get_recording_id( counters_reader: &AeronCountersReader, counter_id: i32, ) -> Result<i64, AeronCError>
Return the recordingId embedded in the key of the given counter if it is indeed a “recording position” counter. Otherwise return -1.