AeronAgentCloseFuncCallback

Trait AeronAgentCloseFuncCallback 

pub trait AeronAgentCloseFuncCallback {
    // Required method
    fn handle_aeron_agent_on_close_func(&mut self);
}
(note you must copy any arguments that you use afterwards even those with static lifetimes)

Required Methods

Implementors

Source

impl AeronAgentCloseFuncCallback for AeronAgentCloseFuncLogger

Source

impl AeronAgentCloseFuncCallback for NoHandler

Source

impl<F: FnMut()> AeronAgentCloseFuncCallback for F

Any closure with the matching signature is a callback: methods that retain it heap-allocate it into a Handler owned by the registering resource.

Source

impl<T: AeronAgentCloseFuncCallback> AeronAgentCloseFuncCallback for Handler<T>

Pass an existing Handler clone anywhere a callback value is expected, e.g. to share one callback instance across several registrations.