AeronAgentDoWorkFuncCallback

Trait AeronAgentDoWorkFuncCallback 

pub trait AeronAgentDoWorkFuncCallback {
    // Required method
    fn handle_aeron_agent_do_work_func(&mut self) -> c_int;
}
(note you must copy any arguments that you use afterwards even those with static lifetimes)

Required Methods

Implementors

Source

impl AeronAgentDoWorkFuncCallback for AeronAgentDoWorkFuncLogger

Source

impl AeronAgentDoWorkFuncCallback for NoHandler

Source

impl<F: FnMut() -> c_int> AeronAgentDoWorkFuncCallback for F

Any closure with the matching signature is a callback: methods that retain it heap-allocate it into a Handler owned by the registering resource.

Source

impl<T: AeronAgentDoWorkFuncCallback> AeronAgentDoWorkFuncCallback for Handler<T>

Pass an existing Handler clone anywhere a callback value is expected, e.g. to share one callback instance across several registrations.