AeronArchiveCredentialsChallengeSupplierFuncCallback

Trait AeronArchiveCredentialsChallengeSupplierFuncCallback 

pub trait AeronArchiveCredentialsChallengeSupplierFuncCallback {
    // Required method
    fn handle_aeron_archive_credentials_challenge_supplier_func(
        &mut self,
        encoded_challenge: AeronArchiveEncodedCredentials,
    ) -> *mut aeron_archive_encoded_credentials_t;
}
Callback to return encoded credentials given a specific encoded challenge.

@param encoded_challenge to use to generate the encoded credentials @return encoded credentials to include with the challenge response

(note you must copy any arguments that you use afterwards even those with static lifetimes)

Required Methods

Implementors

Source

impl AeronArchiveCredentialsChallengeSupplierFuncCallback for AeronArchiveCredentialsChallengeSupplierFuncLogger

Source

impl AeronArchiveCredentialsChallengeSupplierFuncCallback for NoHandler

Source

impl<F: FnMut(AeronArchiveEncodedCredentials) -> *mut aeron_archive_encoded_credentials_t> AeronArchiveCredentialsChallengeSupplierFuncCallback for F

Any closure with the matching signature is a callback: methods that retain it heap-allocate it into a Handler owned by the registering resource.

Source

impl<T: AeronArchiveCredentialsChallengeSupplierFuncCallback> AeronArchiveCredentialsChallengeSupplierFuncCallback for Handler<T>

Pass an existing Handler clone anywhere a callback value is expected, e.g. to share one callback instance across several registrations.