AeronArchiveDelegatingInvokerFuncCallback

Trait AeronArchiveDelegatingInvokerFuncCallback 

pub trait AeronArchiveDelegatingInvokerFuncCallback {
    // Required method
    fn handle_aeron_archive_delegating_invoker_func(&mut self);
}
Callback to allow execution of a delegating invoker to be run.

(note you must copy any arguments that you use afterwards even those with static lifetimes)

Required Methods

Implementors

Source

impl AeronArchiveDelegatingInvokerFuncCallback for AeronArchiveDelegatingInvokerFuncLogger

Source

impl AeronArchiveDelegatingInvokerFuncCallback for NoHandler

Source

impl<F: FnMut()> AeronArchiveDelegatingInvokerFuncCallback for F

Any closure with the matching signature is a callback: methods that retain it heap-allocate it into a Handler owned by the registering resource.

Source

impl<T: AeronArchiveDelegatingInvokerFuncCallback> AeronArchiveDelegatingInvokerFuncCallback for Handler<T>

Pass an existing Handler clone anywhere a callback value is expected, e.g. to share one callback instance across several registrations.