AeronArchiveRecordingDescriptorConsumerFuncCallback

Trait AeronArchiveRecordingDescriptorConsumerFuncCallback 

pub trait AeronArchiveRecordingDescriptorConsumerFuncCallback {
    // Required method
    fn handle_aeron_archive_recording_descriptor_consumer_func(
        &mut self,
        recording_descriptor: AeronArchiveRecordingDescriptor,
    );
}
Callback to return recording descriptors.

(note you must copy any arguments that you use afterwards even those with static lifetimes)

Required Methods

Implementors

Source

impl AeronArchiveRecordingDescriptorConsumerFuncCallback for AeronArchiveRecordingDescriptorConsumerFuncLogger

Source

impl AeronArchiveRecordingDescriptorConsumerFuncCallback for NoHandler

Source

impl<F: FnMut(AeronArchiveRecordingDescriptor)> AeronArchiveRecordingDescriptorConsumerFuncCallback for F

Any closure with the matching signature is a callback: methods that retain it heap-allocate it into a Handler owned by the registering resource.

Source

impl<T: AeronArchiveRecordingDescriptorConsumerFuncCallback> AeronArchiveRecordingDescriptorConsumerFuncCallback for Handler<T>

Pass an existing Handler clone anywhere a callback value is expected, e.g. to share one callback instance across several registrations.