AeronArchiveRecordingSignalConsumerFuncCallback

Trait AeronArchiveRecordingSignalConsumerFuncCallback 

pub trait AeronArchiveRecordingSignalConsumerFuncCallback {
    // Required method
    fn handle_aeron_archive_recording_signal_consumer_func(
        &mut self,
        recording_signal: AeronArchiveRecordingSignal,
    );
}
Callback to return recording signals.

(note you must copy any arguments that you use afterwards even those with static lifetimes)

Required Methods

Implementors

Source

impl AeronArchiveRecordingSignalConsumerFuncCallback for AeronArchiveRecordingSignalConsumerFuncLogger

Source

impl AeronArchiveRecordingSignalConsumerFuncCallback for NoHandler

Source

impl<F: FnMut(AeronArchiveRecordingSignal)> AeronArchiveRecordingSignalConsumerFuncCallback for F

Any closure with the matching signature is a callback: methods that retain it heap-allocate it into a Handler owned by the registering resource.

Source

impl<T: AeronArchiveRecordingSignalConsumerFuncCallback> AeronArchiveRecordingSignalConsumerFuncCallback for Handler<T>

Pass an existing Handler clone anywhere a callback value is expected, e.g. to share one callback instance across several registrations.