pub trait AeronAvailableCounterCallback {
// Required method
fn handle_aeron_on_available_counter(
&mut self,
counters_reader: AeronCountersReader,
registration_id: i64,
counter_id: i32,
);
}Expand description
Function called by aeron_client_t to deliver notifications that a counter has been added to the driver.
@param clientd to be returned in the call. @param counters_reader that holds the counter. @param registration_id of the counter. @param counter_id of the counter.
(note you must copy any arguments that you use afterwards even those with static lifetimes)
Required Methods
fn handle_aeron_on_available_counter( &mut self, counters_reader: AeronCountersReader, registration_id: i64, counter_id: i32, )
Implementors
impl AeronAvailableCounterCallback for AeronAvailableCounterLogger
impl AeronAvailableCounterCallback for NoHandler
impl<F: FnMut(AeronCountersReader, i64, i32)> AeronAvailableCounterCallback for F
Any closure with the matching signature is a callback: methods that retain it
heap-allocate it into a Handler owned by the registering resource.
impl<T: AeronAvailableCounterCallback> AeronAvailableCounterCallback for Handler<T>
Pass an existing Handler clone anywhere a callback value is expected, e.g.
to share one callback instance across several registrations.