AeronAvailableImageCallback

Trait AeronAvailableImageCallback 

pub trait AeronAvailableImageCallback {
    // Required method
    fn handle_aeron_on_available_image(
        &mut self,
        subscription: AeronSubscription,
        image: AeronImage,
    );
}
Function called by aeron_client_t to deliver notifications that an aeron_image_t was added.

@param clientd to be returned in the call. @param subscription that image is part of. @param image that has become available.

(note you must copy any arguments that you use afterwards even those with static lifetimes)

Required Methods

Implementors

Source

impl AeronAvailableImageCallback for AeronAvailableImageLogger

Source

impl AeronAvailableImageCallback for NoHandler

Source

impl<F: FnMut(AeronSubscription, AeronImage)> AeronAvailableImageCallback for F

Any closure with the matching signature is a callback: methods that retain it heap-allocate it into a Handler owned by the registering resource.

Source

impl<T: AeronAvailableImageCallback> AeronAvailableImageCallback for Handler<T>

Pass an existing Handler clone anywhere a callback value is expected, e.g. to share one callback instance across several registrations.