pub trait AeronBlockHandlerCallback {
// Required method
fn handle_aeron_block_handler(
&mut self,
buffer: &[u8],
session_id: i32,
term_id: i32,
);
}Expand description
Callback for handling a block of messages being read from a log.
@param clientd passed to the block poll function. @param buffer containing the block of message fragments. @param offset at which the block begins, including any frame headers. @param length of the block in bytes, including any frame headers that is aligned. @param session_id of the stream containing this block of message fragments. @param term_id of the stream containing this block of message fragments.
(note you must copy any arguments that you use afterwards even those with static lifetimes)
Required Methods
fn handle_aeron_block_handler( &mut self, buffer: &[u8], session_id: i32, term_id: i32, )
Implementors
impl AeronBlockHandlerCallback for AeronBlockHandlerLogger
impl AeronBlockHandlerCallback for NoHandler
impl<F: FnMut(&[u8], i32, i32)> AeronBlockHandlerCallback for F
Any closure with the matching signature is a callback: methods that retain it
heap-allocate it into a Handler owned by the registering resource.
impl<T: AeronBlockHandlerCallback> AeronBlockHandlerCallback for Handler<T>
Pass an existing Handler clone anywhere a callback value is expected, e.g.
to share one callback instance across several registrations.