AeronCloseClientCallback

Trait AeronCloseClientCallback 

pub trait AeronCloseClientCallback {
    // Required method
    fn handle_aeron_on_close_client(&mut self);
}
Function called by aeron_client_t to deliver notifications that the client is closing.

@param clientd to be returned in the call.

(note you must copy any arguments that you use afterwards even those with static lifetimes)

Required Methods

Implementors

Source

impl AeronCloseClientCallback for AeronCloseClientLogger

Source

impl AeronCloseClientCallback for NoHandler

Source

impl<F: FnMut()> AeronCloseClientCallback for F

Any closure with the matching signature is a callback: methods that retain it heap-allocate it into a Handler owned by the registering resource.

Source

impl<T: AeronCloseClientCallback> AeronCloseClientCallback for Handler<T>

Pass an existing Handler clone anywhere a callback value is expected, e.g. to share one callback instance across several registrations.