AeronCountersReaderForeachCounterFuncCallback

Trait AeronCountersReaderForeachCounterFuncCallback 

pub trait AeronCountersReaderForeachCounterFuncCallback {
    // Required method
    fn handle_aeron_counters_reader_foreach_counter_func(
        &mut self,
        value: i64,
        id: i32,
        type_id: i32,
        key: &[u8],
        label: &str,
    );
}
Function called by aeron_counters_reader_foreach_counter for each counter in the aeron_counters_reader_t.

@param value of the counter. @param id of the counter. @param label for the counter. @param label_length for the counter. @param clientd to be returned in the call

(note you must copy any arguments that you use afterwards even those with static lifetimes)

Required Methods

fn handle_aeron_counters_reader_foreach_counter_func( &mut self, value: i64, id: i32, type_id: i32, key: &[u8], label: &str, )

Implementors

Source

impl AeronCountersReaderForeachCounterFuncCallback for AeronCountersReaderForeachCounterFuncLogger

Source

impl AeronCountersReaderForeachCounterFuncCallback for NoHandler

Source

impl<F: FnMut(i64, i32, i32, &[u8], &str)> AeronCountersReaderForeachCounterFuncCallback for F

Any closure with the matching signature is a callback: methods that retain it heap-allocate it into a Handler owned by the registering resource.

Source

impl<T: AeronCountersReaderForeachCounterFuncCallback> AeronCountersReaderForeachCounterFuncCallback for Handler<T>

Pass an existing Handler clone anywhere a callback value is expected, e.g. to share one callback instance across several registrations.