AeronErrorHandlerCallback

Trait AeronErrorHandlerCallback 

pub trait AeronErrorHandlerCallback {
    // Required method
    fn handle_aeron_error_handler(&mut self, errcode: c_int, message: &str);
}
The error handler to be called when an error occurs.

(note you must copy any arguments that you use afterwards even those with static lifetimes)

Required Methods

fn handle_aeron_error_handler(&mut self, errcode: c_int, message: &str)

Implementors

Source

impl AeronErrorHandlerCallback for AeronErrorHandlerLogger

Source

impl AeronErrorHandlerCallback for AeronErrorLogger

Source

impl AeronErrorHandlerCallback for NoHandler

Source

impl<F: FnMut(c_int, &str)> AeronErrorHandlerCallback for F

Any closure with the matching signature is a callback: methods that retain it heap-allocate it into a Handler owned by the registering resource.

Source

impl<T: AeronErrorHandlerCallback> AeronErrorHandlerCallback for Handler<T>

Pass an existing Handler clone anywhere a callback value is expected, e.g. to share one callback instance across several registrations.