AeronIdleStrategyFuncCallback

Trait AeronIdleStrategyFuncCallback 

pub trait AeronIdleStrategyFuncCallback {
    // Required method
    fn handle_aeron_idle_strategy_func(&mut self, work_count: c_int);
}
(note you must copy any arguments that you use afterwards even those with static lifetimes)

Required Methods

fn handle_aeron_idle_strategy_func(&mut self, work_count: c_int)

Implementors

Source

impl AeronIdleStrategyFuncCallback for AeronIdleStrategyFuncLogger

Source

impl AeronIdleStrategyFuncCallback for NoHandler

Source

impl<F: FnMut(c_int)> AeronIdleStrategyFuncCallback for F

Any closure with the matching signature is a callback: methods that retain it heap-allocate it into a Handler owned by the registering resource.

Source

impl<T: AeronIdleStrategyFuncCallback> AeronIdleStrategyFuncCallback for Handler<T>

Pass an existing Handler clone anywhere a callback value is expected, e.g. to share one callback instance across several registrations.