AeronNotificationCallback

Trait AeronNotificationCallback 

pub trait AeronNotificationCallback {
    // Required method
    fn handle_aeron_notification(&mut self);
}
Generalised notification callback.

(note you must copy any arguments that you use afterwards even those with static lifetimes)

Required Methods

Implementors

Source

impl AeronNotificationCallback for AeronNotificationLogger

Source

impl AeronNotificationCallback for NoHandler

Source

impl<F: FnMut()> AeronNotificationCallback for F

Any closure with the matching signature is a callback: methods that retain it heap-allocate it into a Handler owned by the registering resource.

Source

impl<T: AeronNotificationCallback> AeronNotificationCallback for Handler<T>

Pass an existing Handler clone anywhere a callback value is expected, e.g. to share one callback instance across several registrations.