AeronPublicationErrorFrameHandlerCallback

Trait AeronPublicationErrorFrameHandlerCallback 

pub trait AeronPublicationErrorFrameHandlerCallback {
    // Required method
    fn handle_aeron_publication_error_frame_handler(
        &mut self,
        error_frame: AeronPublicationErrorValues,
    );
}
The error frame handler to be called when the driver notifies the client about an error frame being received. The data passed to this callback will only be valid for the lifetime of the callback. The user should use aeron_publication_error_values_copy if they require the data to live longer than that.

(note you must copy any arguments that you use afterwards even those with static lifetimes)

Required Methods

Implementors

Source

impl AeronPublicationErrorFrameHandlerCallback for AeronPublicationErrorFrameHandlerLogger

Source

impl AeronPublicationErrorFrameHandlerCallback for NoHandler

Source

impl<F: FnMut(AeronPublicationErrorValues)> AeronPublicationErrorFrameHandlerCallback for F

Any closure with the matching signature is a callback: methods that retain it heap-allocate it into a Handler owned by the registering resource.

Source

impl<T: AeronPublicationErrorFrameHandlerCallback> AeronPublicationErrorFrameHandlerCallback for Handler<T>

Pass an existing Handler clone anywhere a callback value is expected, e.g. to share one callback instance across several registrations.