pub trait AeronReservedValueSupplierCallback {
// Required method
fn handle_aeron_reserved_value_supplier(&mut self, buffer: &mut [u8]) -> i64;
}Expand description
Function called when filling in the reserved value field of a message.
@param clientd passed to the offer function. @param buffer of the entire frame, including Aeron data header. @param frame_length of the entire frame.
(note you must copy any arguments that you use afterwards even those with static lifetimes)
Required Methods
fn handle_aeron_reserved_value_supplier(&mut self, buffer: &mut [u8]) -> i64
Implementors
impl AeronReservedValueSupplierCallback for AeronReservedValueSupplierLogger
impl AeronReservedValueSupplierCallback for NoHandler
impl<F: FnMut(&mut [u8]) -> i64> AeronReservedValueSupplierCallback for F
Any closure with the matching signature is a callback: methods that retain it
heap-allocate it into a Handler owned by the registering resource.
impl<T: AeronReservedValueSupplierCallback> AeronReservedValueSupplierCallback for Handler<T>
Pass an existing Handler clone anywhere a callback value is expected, e.g.
to share one callback instance across several registrations.