AeronUnavailableCounterCallback

Trait AeronUnavailableCounterCallback 

pub trait AeronUnavailableCounterCallback {
    // Required method
    fn handle_aeron_on_unavailable_counter(
        &mut self,
        counters_reader: AeronCountersReader,
        registration_id: i64,
        counter_id: i32,
    );
}
Function called by aeron_client_t to deliver notifications that a counter has been removed from the driver.

@param clientd to be returned in the call. @param counters_reader that holds the counter. @param registration_id of the counter. @param counter_id of the counter.

(note you must copy any arguments that you use afterwards even those with static lifetimes)

Required Methods

fn handle_aeron_on_unavailable_counter( &mut self, counters_reader: AeronCountersReader, registration_id: i64, counter_id: i32, )

Implementors

Source

impl AeronUnavailableCounterCallback for AeronUnavailableCounterLogger

Source

impl AeronUnavailableCounterCallback for NoHandler

Source

impl<F: FnMut(AeronCountersReader, i64, i32)> AeronUnavailableCounterCallback for F

Any closure with the matching signature is a callback: methods that retain it heap-allocate it into a Handler owned by the registering resource.

Source

impl<T: AeronUnavailableCounterCallback> AeronUnavailableCounterCallback for Handler<T>

Pass an existing Handler clone anywhere a callback value is expected, e.g. to share one callback instance across several registrations.