AeronUnavailableImageCallback

Trait AeronUnavailableImageCallback 

pub trait AeronUnavailableImageCallback {
    // Required method
    fn handle_aeron_on_unavailable_image(
        &mut self,
        subscription: AeronSubscription,
        image: AeronImage,
    );
}
Function called by aeron_client_t to deliver notifications that an aeron_image_t has been removed from use and should not be used any longer.

@param clientd to be returned in the call. @param subscription that image is part of. @param image that has become unavailable.

(note you must copy any arguments that you use afterwards even those with static lifetimes)

Required Methods

Implementors

Source

impl AeronUnavailableImageCallback for AeronUnavailableImageLogger

Source

impl AeronUnavailableImageCallback for NoHandler

Source

impl<F: FnMut(AeronSubscription, AeronImage)> AeronUnavailableImageCallback for F

Any closure with the matching signature is a callback: methods that retain it heap-allocate it into a Handler owned by the registering resource.

Source

impl<T: AeronUnavailableImageCallback> AeronUnavailableImageCallback for Handler<T>

Pass an existing Handler clone anywhere a callback value is expected, e.g. to share one callback instance across several registrations.