pub trait AeronAvailableImageCallback {
// Required method
fn handle_aeron_on_available_image(
&mut self,
subscription: AeronSubscription,
image: AeronImage,
);
}Expand description
Function called by aeron_client_t to deliver notifications that an aeron_image_t was added.
@param clientd to be returned in the call. @param subscription that image is part of. @param image that has become available.
(note you must copy any arguments that you use afterwards even those with static lifetimes)
Required Methods
fn handle_aeron_on_available_image( &mut self, subscription: AeronSubscription, image: AeronImage, )
Implementors
impl AeronAvailableImageCallback for AeronAvailableImageLogger
impl AeronAvailableImageCallback for NoHandler
impl<F: FnMut(AeronSubscription, AeronImage)> AeronAvailableImageCallback for F
Any closure with the matching signature is a callback: methods that retain it
heap-allocate it into a Handler owned by the registering resource.
impl<T: AeronAvailableImageCallback> AeronAvailableImageCallback for Handler<T>
Pass an existing Handler clone anywhere a callback value is expected, e.g.
to share one callback instance across several registrations.