pub trait AeronNewSubscriptionCallback {
// Required method
fn handle_aeron_on_new_subscription(
&mut self,
channel: &str,
stream_id: i32,
correlation_id: i64,
);
}Expand description
Function called by aeron_client_t to deliver notification that the media driver has added an aeron_subscription_t successfully.
Implementations should do the minimum work for handing off state to another thread for later processing.
@param clientd to be returned in the call @param channel of the subscription @param stream_id within the channel of the subscription @param session_id of the subscription @param correlation_id used by the subscription
(note you must copy any arguments that you use afterwards even those with static lifetimes)
Required Methods
fn handle_aeron_on_new_subscription( &mut self, channel: &str, stream_id: i32, correlation_id: i64, )
Implementors
impl AeronNewSubscriptionCallback for AeronNewSubscriptionLogger
impl AeronNewSubscriptionCallback for NoHandler
impl<F: FnMut(&str, i32, i64)> AeronNewSubscriptionCallback for F
Any closure with the matching signature is a callback: methods that retain it
heap-allocate it into a Handler owned by the registering resource.
impl<T: AeronNewSubscriptionCallback> AeronNewSubscriptionCallback for Handler<T>
Pass an existing Handler clone anywhere a callback value is expected, e.g.
to share one callback instance across several registrations.